@@ -3,7 +3,7 @@ import json
 from flask import Response, abort, render_template_string, request
 from flask.views import View
 from strawberry.http import GraphQLHTTPResponse, process_result
-from strawberry.schema import ExecutionResult
+from strawberry.types import ExecutionResult
 
 from ..schema import BaseSchema
 from .graphiql import render_graphiql_page
@@ -13,7 +13,9 @@ class GraphQLView(View):
     methods = ["GET", "POST"]
 
     def __init__(
-        self, schema: BaseSchema, graphiql: bool = True,
+        self,
+        schema: BaseSchema,
+        graphiql: bool = True,
     ):
         self.graphiql = graphiql
         self.schema = schema
@@ -61,5 +63,7 @@ class GraphQLView(View):
         response_data = self.process_result(result)
 
         return Response(
-            json.dumps(response_data), status=200, content_type="application/json",
+            json.dumps(response_data),
+            status=200,
+            content_type="application/json",
         )
