@@ -121,3 +121,12 @@ def type(
 
 input = partial(type, is_input=True)
 interface = partial(type, is_interface=True)
+
+
+__all__ = [
+    "FederationTypeParams",
+    "TypeDefinition",
+    "input",
+    "interface",
+    "type",
+]
